@@ -1,6 +1,6 @@
 /*
     findep
-    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
 #include "ia32/memory.h"
 #include "ia32/message.h"
 #include "ia32/process.h"
-#include "misc/fileio.h"
 #include "misc/opcode.h"
 #include "misc/peimage.h"
 
@@ -215,7 +214,9 @@ main (int   argc,
   GHashTable *ghash_entry, *ghash_ignore;
 
   /* ja:初期化 */
+#if ! GTK_CHECK_VERSION (2,24,0)
   gtk_set_locale ();
+#endif /* not GTK_CHECK_VERSION (2,24,0) */
   gtk_init (&argc, &argv);
 
   /* ja:引数 */
@@ -421,14 +422,17 @@ main (int   argc,
             {
               if (steps (mnemonic) >= MINSTEP)
                 {
-                  gssize length;
-                  gchar *sha1;
-                  guint8 *data;
+                  gsize length;
+                  gchar *sha1 = NULL;
+                  guchar *data;
 
-                  data = fileio_load (argv[i], &length);
-                  sha1 = data ? g_compute_checksum_for_data (G_CHECKSUM_SHA1,
-                                                        data, length) : NULL;
-                  g_free (data);
+                  if (g_file_get_contents (argv[i],
+                                            (gchar **)&data, &length, NULL))
+                    {
+                      sha1 = g_compute_checksum_for_data (G_CHECKSUM_SHA1,
+                                                                data, length);
+                      g_free (data);
+                    }
                   if (!sha1)
                     {
                       g_fprintf (stderr, "%s : SHA-1 error.\n", argv[i]);
@@ -579,7 +583,7 @@ main (int   argc,
       gchar *data;
 
       data = g_key_file_to_data (key_file, &length, NULL);
-      if (!data || !fileio_save (file, data, length))
+      if (!data || !g_file_set_contents (file, data, length, NULL))
         {
           g_fprintf (stderr, "\'%s\' save error.\n", file);
           result = FALSE;
@@ -714,13 +718,12 @@ main (int   argc,
   if (cmd == 'f')
     {
       /* ja:探査 */
-      gssize length;
+      gsize length;
       guint8 *image;
 
       g_fprintf (stderr, "entry  : %d\nignore : %d\n\n",
                                     g_hash_table_size (ghash_entry), n_ignore);
-      image = fileio_load (argv[index], &length);
-      if (image)
+      if (g_file_get_contents (argv[index], (gchar **)&image, &length, NULL))
         {
           guint32 header;
           GList *glist = NULL;
@@ -822,7 +825,8 @@ main (int   argc,
                               g_free (data);
                               length = pe_ioh_get_size_of_image (image);
                             }
-                          if (!fileio_save (argv[index + 1], image, length))
+                          if (!g_file_set_contents (argv[index + 1],
+                                        (const gchar *)image, length, NULL))
                             {
                               g_fprintf (stderr, "\'%s\' save error.\n",
                                                             argv[index + 1]);
