@@ -1,6 +1,6 @@
 /*
     IA32
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2013 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -318,7 +318,7 @@ typedef struct _ThreadEnvironmentBlock { guint8 dummy[TEB_SIZE]; } ThreadEnviron
 #endif /* not MAXIMUM_SUPPORTED_EXTENSION */
 #ifndef EXCEPTION_MAXIMUM_PARAMETERS
 # define EXCEPTION_MAXIMUM_PARAMETERS 15
-#endif /* not not EXCEPTION_MAXIMUM_PARAMETERS */
+#endif /* not EXCEPTION_MAXIMUM_PARAMETERS */
 #ifndef EXCEPTION_ACCESS_VIOLATION
 # define EXCEPTION_ACCESS_VIOLATION         0xc0000005
 #endif /* not EXCEPTION_ACCESS_VIOLATION */
