@@ -1,6 +1,6 @@
 /*
     IA32
-    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,13 +18,6 @@
 #include "mtxdm.h"
 
 
-/* GetDispenserManager ordinal = 1, argument = 0 */
-static gboolean mtxdm_GetDispenserManager (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
 Ia32Export ia32_mtxdm_exports[] = {
-{ 0,    1, "GetDispenserManager", mtxdm_GetDispenserManager},
-{ 0,    0, NULL,                  NULL}};
+{0, 1, "GetDispenserManager", NULL},
+{G_MAXINT, 0, NULL, NULL}};
